import { AtlasTools } from "./tools/atlas/tools.js";
import { MongoDbTools } from "./tools/mongodb/tools.js";
import logger, { initializeLogger } from "./logger.js";
import { mongoLogId } from "mongodb-log-writer";
export class Server {
    constructor({ mcpServer, session }) {
        this.mcpServer = mcpServer;
        this.session = session;
    }
    async connect(transport) {
        this.mcpServer.server.registerCapabilities({ logging: {} });
        this.registerTools();
        await initializeLogger(this.mcpServer);
        await this.mcpServer.connect(transport);
        logger.info(mongoLogId(1000004), "server", `Server started with transport ${transport.constructor.name}`);
    }
    async close() {
        await this.session.close();
        await this.mcpServer.close();
    }
    registerTools() {
        for (const tool of [...AtlasTools, ...MongoDbTools]) {
            new tool(this.session).register(this.mcpServer);
        }
    }
}
//# sourceMappingURL=server.js.map