import { z } from "zod";
import { AtlasToolBase } from "./atlasTool.js";
export class InspectClusterTool extends AtlasToolBase {
    constructor() {
        super(...arguments);
        this.name = "atlas-inspect-cluster";
        this.description = "Inspect MongoDB Atlas cluster";
        this.argsShape = {
            projectId: z.string().describe("Atlas project ID"),
            clusterName: z.string().describe("Atlas cluster name"),
        };
    }
    async execute({ projectId, clusterName }) {
        this.session.ensureAuthenticated();
        const cluster = await this.session.apiClient.getCluster({
            params: {
                path: {
                    groupId: projectId,
                    clusterName,
                },
            },
        });
        return this.formatOutput(cluster);
    }
    formatOutput(cluster) {
        if (!cluster) {
            throw new Error("Cluster not found");
        }
        return {
            content: [
                {
                    type: "text",
                    text: `Cluster Name | State | MongoDB Version | Connection String
----------------|----------------|----------------|----------------|----------------
${cluster.name} | ${cluster.stateName} | ${cluster.mongoDBVersion || "N/A"} | ${cluster.connectionStrings?.standard || "N/A"}`,
                },
            ],
        };
    }
}
//# sourceMappingURL=inspectCluster.js.map