import { AtlasToolBase } from "./atlasTool.js";
export class ListProjectsTool extends AtlasToolBase {
    constructor() {
        super(...arguments);
        this.name = "atlas-list-projects";
        this.description = "List MongoDB Atlas projects";
        this.argsShape = {};
    }
    async execute() {
        this.session.ensureAuthenticated();
        const data = await this.session.apiClient.listProjects();
        if (!data?.results?.length) {
            throw new Error("No projects found in your MongoDB Atlas account.");
        }
        // Format projects as a table
        const rows = data.results
            .map((project) => {
            const createdAt = project.created ? new Date(project.created).toLocaleString() : "N/A";
            return `${project.name} | ${project.id} | ${createdAt}`;
        })
            .join("\n");
        const formattedProjects = `Project Name | Project ID | Created At
----------------| ----------------| ----------------
${rows}`;
        return {
            content: [{ type: "text", text: formattedProjects }],
        };
    }
}
//# sourceMappingURL=listProjects.js.map