import { z } from "zod";
import { DbOperationArgs, MongoDBToolBase } from "./mongodbTool.js";
export class CreateIndexTool extends MongoDBToolBase {
    constructor() {
        super(...arguments);
        this.name = "create-index";
        this.description = "Create an index for a collection";
        this.argsShape = {
            ...DbOperationArgs,
            keys: z.record(z.string(), z.custom()).describe("The index definition"),
        };
        this.operationType = "create";
    }
    async execute({ database, collection, keys }) {
        const provider = await this.ensureConnected();
        const indexes = await provider.createIndexes(database, collection, [
            {
                key: keys,
            },
        ]);
        return {
            content: [
                {
                    text: `Created the index \`${indexes[0]}\``,
                    type: "text",
                },
            ],
        };
    }
}
//# sourceMappingURL=createIndex.js.map