import { z } from "zod";
import { DbOperationArgs, MongoDBToolBase } from "../mongodbTool.js";
export class DeleteOneTool extends MongoDBToolBase {
    constructor() {
        super(...arguments);
        this.name = "delete-one";
        this.description = "Removes a single document that match the filter from a MongoDB collection";
        this.argsShape = {
            ...DbOperationArgs,
            filter: z
                .object({})
                .passthrough()
                .optional()
                .describe("The query filter, specifying the deletion criteria. Matches the syntax of the filter argument of db.collection.deleteMany()"),
        };
        this.operationType = "delete";
    }
    async execute({ database, collection, filter, }) {
        const provider = await this.ensureConnected();
        const result = await provider.deleteOne(database, collection, filter);
        return {
            content: [
                {
                    text: `Deleted \`${result.deletedCount}\` documents from collection \`${collection}\``,
                    type: "text",
                },
            ],
        };
    }
}
//# sourceMappingURL=deleteOne.js.map