import { DbOperationArgs, MongoDBToolBase } from "../mongodbTool.js";
import { parseSchema } from "mongodb-schema";
export class CollectionSchemaTool extends MongoDBToolBase {
    constructor() {
        super(...arguments);
        this.name = "collection-schema";
        this.description = "Describe the schema for a collection";
        this.argsShape = DbOperationArgs;
        this.operationType = "metadata";
    }
    async execute({ database, collection }) {
        const provider = await this.ensureConnected();
        const documents = await provider.find(database, collection, {}, { limit: 5 }).toArray();
        const schema = await parseSchema(documents);
        return {
            content: [
                {
                    text: `Found ${schema.fields.length} fields in the schema for \`${database}.${collection}\``,
                    type: "text",
                },
                {
                    text: this.formatFieldOutput(schema.fields),
                    type: "text",
                },
            ],
        };
    }
    formatFieldOutput(fields) {
        let result = "| Field | Type | Confidence |\n";
        result += "|-------|------|-------------|\n";
        for (const field of fields) {
            const fieldType = Array.isArray(field.type) ? field.type.join(", ") : field.type;
            result += `| ${field.name} | \`${fieldType}\` | ${(field.probability * 100).toFixed(0)}% |\n`;
        }
        return result;
    }
}
//# sourceMappingURL=collectionSchema.js.map