import { DbOperationArgs, MongoDBToolBase } from "../mongodbTool.js";
export class CollectionStorageSizeTool extends MongoDBToolBase {
    constructor() {
        super(...arguments);
        this.name = "collection-storage-size";
        this.description = "Gets the size of the collection in MB";
        this.argsShape = DbOperationArgs;
        this.operationType = "metadata";
    }
    async execute({ database, collection }) {
        const provider = await this.ensureConnected();
        const [{ value }] = (await provider
            .aggregate(database, collection, [
            { $collStats: { storageStats: {} } },
            { $group: { _id: null, value: { $sum: "$storageStats.storageSize" } } },
        ])
            .toArray());
        return {
            content: [
                {
                    text: `The size of \`${database}.${collection}\` is \`${(value / 1024 / 1024).toFixed(2)} MB\``,
                    type: "text",
                },
            ],
        };
    }
}
//# sourceMappingURL=collectionStorageSize.js.map