import { z } from "zod";
import { MongoDBToolBase } from "../mongodbTool.js";
export class RenameCollectionTool extends MongoDBToolBase {
    constructor() {
        super(...arguments);
        this.name = "rename-collection";
        this.description = "Renames a collection in a MongoDB database";
        this.argsShape = {
            collection: z.string().describe("Collection name"),
            database: z.string().describe("Database name"),
            newName: z.string().describe("The new name for the collection"),
            dropTarget: z.boolean().optional().default(false).describe("If true, drops the target collection if it exists"),
        };
        this.operationType = "update";
    }
    async execute({ database, collection, newName, dropTarget, }) {
        const provider = await this.ensureConnected();
        const result = await provider.renameCollection(database, collection, newName, {
            dropTarget,
        });
        return {
            content: [
                {
                    text: `Collection \`${collection}\` renamed to \`${result.collectionName}\` in database \`${database}\`.`,
                    type: "text",
                },
            ],
        };
    }
}
//# sourceMappingURL=renameCollection.js.map